package com.diagbot.web;


import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.ConceptDTO;
import com.diagbot.dto.LibraryDetailDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.LibraryDetailFacade;
import com.diagbot.vo.AmendTermVo;
import com.diagbot.vo.GetAllInformationVO;
import com.diagbot.vo.KnowledgeVo;
import com.diagbot.vo.RemoveConceptKnowledgeVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;


/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author Weixuan Huang
 * @since 2019-01-30
 */
@RestController
@RequestMapping("/Knowledge")
@Api(value = "标准术语静态知识API", tags = { "标准术语静态知识API" })

public class LibraryDetailController {
    @Autowired
    private LibraryDetailFacade libraryDetailFacade;

    @ApiOperation(value = "查询所有术语静态知识")
    @PostMapping("getAllKnowledge")
    @SysLogger("getAllKnowledge")
    public RespDTO<IPage<LibraryDetailDTO>> getAllKnowledge(@RequestBody GetAllInformationVO conceptVo) {
        IPage<LibraryDetailDTO> data = libraryDetailFacade.getAllLibraryDetail(conceptVo);

        return RespDTO.onSuc(data);
    }


    @ApiOperation(value = "术语静态知识查询",
            notes = "Term：术语名称, 必填<br>Type：术语类型, 必填<br>" +
                    "Source: 知识来源, 选填<br/>NewType: 知识标题, 选填<br/>")
    @PostMapping("/getConceptKnowledge")
    @SysLogger("getConceptKnowledge")
    public RespDTO<ConceptDTO> getConceptKnowledge(@Valid @RequestBody KnowledgeVo knowledgeVo) {
        ConceptDTO data = libraryDetailFacade.getConceptKnowledge(knowledgeVo);

        return RespDTO.onSuc(data);
    }


    @ApiOperation(value = "术语静态知识修改",
            notes = "NewTerm: 术语名称, 必填<br/>NewType: 术语类型, 必填<br/>" +
                    "Source: 知识来源, 必填<br/>NewType: 知识标题, 必填<br/>")
    @PostMapping("/upsertConceptKnowledge")
    @SysLogger("upsertConceptKnowledge")
    public RespDTO<ConceptDTO> upsertConceptKnowledge(@Valid @RequestBody AmendTermVo amendTermVo) {
        ConceptDTO data = libraryDetailFacade.upsertConceptKnowledge(amendTermVo);

        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "术语静态知识删除",
            notes = "Term: 术语名称, 必填<br/>Type: 术语类型, 必填<br/>" +
                    "Source: 知识来源, 必填<br/>NewType: 知识标题, 必填<br/>")
    @PostMapping("/removeConceptKnowledge")
    @SysLogger("removeConceptKnowledge")
    public RespDTO<Boolean> removeConceptKnowledge(@Valid @RequestBody RemoveConceptKnowledgeVO removeConceptKnowledgeVO) {
        RespDTO<Boolean> resp = new RespDTO<>();
        return RespDTO.onSuc(libraryDetailFacade.removeConceptKnowledge(removeConceptKnowledgeVO));
    }
}
